@@ -40,7 +40,7 @@ _cb_mouse_down(void *data,
         evas_object_del(ctx->over);
      }
    elm_object_focus_set(ctx->layout, EINA_FALSE);
-   edje_object_signal_emit(ctx->base, "about,hide", "terminology");
+   elm_layout_signal_emit(ctx->base, "about,hide", "terminology");
 
    ecore_timer_add(10.0, _cb_del_delay, ctx->layout);
    ctx->layout = NULL;
@@ -96,7 +96,7 @@ about_show(Evas_Object *win, Evas_Object *base, Evas_Object *term,
          "<br>"
          "%s" // LICENSE
          ),
-      PACKAGE_VERSION, 2018,
+      PACKAGE_VERSION, 2019,
       "Boris Faure<br>"
       "Carsten Haitzler<br>"
       "Gustavo Sverzut Barbieri<br>"
@@ -183,16 +183,16 @@ about_show(Evas_Object *win, Evas_Object *base, Evas_Object *term,
    elm_object_part_text_set(o, "terminology.text", txt);
    eina_stringshare_del(txt);
    evas_object_show(o);
-   edje_object_part_swallow(base, "terminology.about", ctx->layout);
+   elm_layout_content_set(base, "terminology.about", ctx->layout);
 
    ctx->over = o = evas_object_rectangle_add(evas_object_evas_get(win));
    evas_object_color_set(o, 0, 0, 0, 0);
-   edje_object_part_swallow(base, "terminology.dismiss", o);
+   elm_layout_content_set(base, "terminology.dismiss", o);
    evas_object_show(o);
    evas_object_event_callback_add(o, EVAS_CALLBACK_MOUSE_DOWN,
                                   _cb_mouse_down, ctx);
 
-   edje_object_signal_emit(base, "about,show", "terminology");
+   elm_layout_signal_emit(base, "about,show", "terminology");
    elm_object_signal_emit(ctx->layout, "begin" ,"terminology");
    elm_object_focus_set(ctx->layout, EINA_TRUE);
 }
