@@ -1,5 +1,3 @@
-#include "coverity.h"
-
 #ifndef _PRIVATE_H__
 #define _PRIVATE_H__ 1
 
@@ -7,7 +5,7 @@
 #include "terminology_config.h"
 #endif
 
-#if HAVE_GETTEXT && ENABLE_NLS
+#if ENABLE_NLS
 #include <libintl.h>
 #define _(string) gettext (string)
 #else
@@ -18,7 +16,15 @@
 
 extern int terminology_starting_up;
 
-#ifdef ENABLE_FUZZING
+/* Uncommenting the following enables processing of testing escape codes in
+ * the normal 'terminology' binary.
+ * This is only useful to write tests
+ */
+#if !defined(ENABLE_FUZZING) && !defined(ENABLE_TESTS)
+//#define ENABLE_TEST_UI
+#endif
+
+#if defined(ENABLE_FUZZING) || defined(ENABLE_TESTS)
 #define EINA_LOG_LEVEL_MAXIMUM (-1)
 #endif
 extern int _log_domain;
